# SCUBAS
SUCBAS: **S**ubmarine **C**ables **U**pset **b**y **A**uroral **S**treams.

## Installation
`scubas` includes both a reusuable Python package (intended to be imported and reused by other projects) and a set of scripts / notebooks using that package. How you should install `scubas` depends on how you intend to use it.

**If you want to run the interactive scripts / notebooks**, you should download this repository and install from it. **If you want to use the library in other projects**, you can either do that or just install the library from a package index or use `pip` installer.

### If you want to run the interactive notebooks

Make sure you have a recent Python version (*Python>=3.7*) and Jupyter installed.

Clone this repository into a suitable location on your computer:

`git clone https://github.com/shibaji7/SCUBAS`

`cd SCUBAS`

`pip install .`

You should now be able to open and run the notebooks within `scripts/` using Jupyter.

### If you want to use the library in other projects

#### From the Python Package Index:

The `scubas` package is distributed on the Python Package Index: https://pypi.org/project/scubas/

`pip install scubas`

#### From the git repository:

Follow the same instructions as installing the interactive notebooks.

## Folder Structure

- `scubas` -  the python package
- `docs` - documentation for the codebase
- `scripts`, etc. - example analysis scripts and Jupyter notebooks

## Citing this Project

- Chakraborty S, Boteler DH, Shi X, Murphy BS, Hartinger MD, Wang X, Lucas G and Baker JBH (2022) Modeling geomagnetic induction in submarine cables. *Front. Phys.* 10:1022475. [doi:10.3389/fphy.2022.1022475](https://doi.org/10.3389/fphy.2022.1022475)
